pub enum Error {
ArithError(Error),
CommitmentError(Error),
SynthesisError(SynthesisError),
Unsupported(String),
DomainCreationFailure,
IndivisibleByVanishingPoly,
UnsatisfiedRelation(String),
InvalidPublicParameters(String),
}Expand description
Error enumerates possible errors during folding scheme operations.
Variants
ArithError(Error)
Error::ArithError indicates an error from the underlying constraint
system.
CommitmentError(Error)
Error::CommitmentError indicates an error from the underlying
commitment scheme.
SynthesisError(SynthesisError)
Error::SynthesisError indicates an error during constraint
synthesis.
Unsupported(String)
Error::Unsupported indicates that a certain use case is not
supported.
DomainCreationFailure
Error::DomainCreationFailure indicates a failure in creating
evaluation domains.
IndivisibleByVanishingPoly
Error::IndivisibleByVanishingPoly indicates that a polynomial is
not divisible by the vanishing polynomial of a certain domain.
UnsatisfiedRelation(String)
Error::UnsatisfiedRelation indicates that a certain relation is not
satisfied.
InvalidPublicParameters(String)
Error::InvalidPublicParameters indicates that the provided public
parameters are invalid.