pub trait FoldingSchemePreprocessor: FoldingSchemeDef {
// Required method
fn preprocess(
config: Self::Config,
rng: impl RngCore,
) -> Result<Self::PublicParam, Error>;
}Expand description
FoldingSchemePreprocessor is the trait for folding scheme preprocessor.
Required Methods
Sourcefn preprocess(
config: Self::Config,
rng: impl RngCore,
) -> Result<Self::PublicParam, Error>
fn preprocess( config: Self::Config, rng: impl RngCore, ) -> Result<Self::PublicParam, Error>
FoldingSchemePreprocessor::preprocess defines the preprocessing
algorithm, which is a randomized algorithm that takes as input the
config / parameterization config of the folding scheme (e.g., size
bounds of the folding scheme) and outputs the public parameters.
Here, the randomness source is controlled by rng.
The security parameter is implicitly specified by the size of underlying fields and groups.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".